@@ -20,6 +20,9 @@ class Config(object):
     # Usage in jupyterlab or script. For renderer plots
     _framework = 'script'
 
+    # Default location for timezones
+    _location = 'Europe/Madrid'
+
     ### ---------------------------------------
     ### -----------------DATA------------------
     ### ---------------------------------------
@@ -28,14 +31,18 @@ class Config(object):
     _combined_devices_name = 'COMBINED_DEVICES'
 
     
-    data = {# Whether or not to reload smartcitizen firmware names from git repo
+    data = {
+            # Whether or not to reload smartcitizen firmware names from git repo
             'reload_firmware_names': True, 
             # Whether or not to load or store cached data (saves time when requesting a lot of data)
             'load_cached_api': True, 
             'store_cached_api': True, 
             # If reloading data from the API, how much gap between the saved data and the
             # latest reading in the API should be ignore
-            'cached_data_margin': 6}
+            'cached_data_margin': 1,
+            # clean_na
+            'clean_na': None
+            }
 
     # If using multiple training datasets, how to call the joint df
     _name_multiple_training_data = 'CDEV'
@@ -104,57 +111,48 @@ class Config(object):
     _baseline_deltas = arange(30, 45, 5)
     # Lambdas for baseline ALS algorithm
     _baseline_als_lambdas = [1e5]
-
-    # TODO - DEFINE IF THIS IS NECESSARY
-    _platform_sensor_ids = {
-        'CO': None,
-        'NO2': None,
-        'H2S': None,
-        'NO': None,
-        'O3': None,
-        'SO2': None
-    }
     
     ### ---------------------------------------
     ### -------------METRICS DATA--------------
     ### ---------------------------------------
     # Molecular weights of certain pollutants for unit convertion
-    _molecular_weights = {
-                            'CO': 28, 
-                            'NO': 30, 
-                            'NO2': 46, 
-                            'O3': 48,
-                            'C6H6': 78,
-                            'SO2': 64,
-                            'H2S': 34
-                        }
+    _molecular_weights =    {
+                                'CO':   28,
+                                'NO':   30,
+                                'NO2':  46,
+                                'O3':   48,
+                                'C6H6': 78,
+                                'SO2':  64,
+                                'H2S':  34
+                            }
+
     # Background concentrations
-    _background_conc = {
-                        'CO': 0, 
-                        'NO2': 8, 
-                        'O3': 40
-                    }
+    _background_conc =      {
+                                'CO':   0,
+                                'NO2':  8,
+                                'O3':   40
+                            }
 
     # Alphasense data
-    _as_sensor_codes = {
-                        '132': 'ASA4_CO',
-                        '133': 'ASA4_H2S',
-                        '130': 'ASA4_NO',
-                        '212': 'ASA4_NO2',
-                        '214': 'ASA4_OX',
-                        '134': 'ASA4_SO2',
-                        '162': 'ASB4_CO',
-                        '133': 'ASB4_H2S',#
-                        '130': 'ASB4_NO', #
-                        '202': 'ASB4_NO2',
-                        '204': 'ASB4_OX',
-                        '164': 'ASB4_SO2'
-    }
+    _as_sensor_codes =      {
+                                '132':  'ASA4_CO',
+                                '133':  'ASA4_H2S',
+                                '130':  'ASA4_NO',
+                                '212':  'ASA4_NO2',
+                                '214':  'ASA4_OX',
+                                '134':  'ASA4_SO2',
+                                '162':  'ASB4_CO',
+                                '133':  'ASB4_H2S',#
+                                '130':  'ASB4_NO', #
+                                '202':  'ASB4_NO2',
+                                '204':  'ASB4_OX',
+                                '164':  'ASB4_SO2'
+                            }
 
     # From Tables 2 and 3 of AAN 803-04
     _as_t_comp = [-30, -20, -10, 0, 10, 20, 30, 40, 50]
 
-    _as_sensor_algs = {
+    _as_sensor_algs =   {
                         'ASA4_CO':  
                                     {
                                         1: ['n_t',      [1.0, 1.0, 1.0, 1.0, -0.2, -0.9, -1.5, -1.5, -1.5]],
@@ -219,7 +217,7 @@ class Config(object):
                                         4: ['kpp_t',    [-4, -4, -4, -4, -4, 0, 20, 140, 450]],
                                         1: ['n_t',      [1.6, 1.6, 1.6, 1.6, 1.6, 1.6, 1.9, 3.0, 5.8]]
                                     },                        
-    }
+                        }
 
     # This look-up table is comprised of channels you want always want to have with the same units and that might come from different sources
     # i.e. pollutant data in various units (ppm or ug/m3) from different analysers
@@ -233,7 +231,7 @@ class Config(object):
                     "HUM": "%rh",
                     "PRESS": "kPa",
                     "PM_(\d|[A,B]_\d)": "ug/m3",
-                    "CO(\D|$)": "ppm",
+                    "CO(\D|$)": "ppb",
                     "NOISE_A": "dBA",
                     "NO\Z": "ppb",
                     "NO2": "ppb",
@@ -241,7 +239,8 @@ class Config(object):
                     "O3": "ppb",
                     "C6H6": "ppb",
                     "H2S": "ppb",
-                    "SO2": "ppb"
+                    "SO2": "ppb",
+                    "CO2": "ppm"
                 }
 
     # This table is used to convert units
@@ -272,7 +271,7 @@ class Config(object):
                         'max_date': None,
                         'frequency': None,
                         'resample': 'mean',
-                        'clean_na': 'fill',
+                        'clean_na': None,
                         'show': True
                     }
 
@@ -326,7 +325,18 @@ class Config(object):
                             'palette': None,
                             'decorators': None,
                             'legend': True
-                            }
+                            },
+                        'uplot': {
+                            'width': 800,
+                            'height': 400,
+                            'ylabel': None,
+                            'size': 3,
+                            'xlabel': 'Date (-)',
+                            'title': None,
+                            'padding-right': 50,
+                            'padding-bottom': 200,
+                            'fontsize': 15
+                        }
                       }
 
     _scatter_plot_def_fmt = {
@@ -484,6 +494,10 @@ class Config(object):
                  'options',
                  'loaded',
                  'hw_id',
+                 'blueprint_url',
+                 'hw_info',
+                 'hw_updated_at',
+                 'description',
                  'latest_postprocessing',
                  'blueprint_loaded_from_url',
                  'hw_loaded_from_url',
