@@ -9,7 +9,7 @@ from scdata.device.process import *
 
 from os.path import join, basename
 from urllib.parse import urlparse
-from pandas import DataFrame
+from pandas import DataFrame, to_datetime
 from traceback import print_exc
 import datetime
 
@@ -33,7 +33,7 @@ class Device(object):
             parameter passed here is overriden by that of the API.
 
         descriptor: dict()
-            Default: empty dict
+            Default: empty: std_out('Empty dataframe, ignoring', 'WARNING') dict
             A dictionary containing information about the device itself. Depending on the blueprint, this descriptor
             needs to have different data. If not all the data is present, the corresponding blueprint's default will 
             be used
@@ -55,20 +55,21 @@ class Device(object):
 
             # Set attributes
             self.set_blueprint_attrs(config.blueprints[blueprint])
-
             self.blueprint_loaded_from_url = False
             self.hw_loaded_from_url = False
 
-        # Descriptor attributes
-        for ditem in descriptor.keys():
-            if type(self.__getattribute__(ditem)) == dict: 
-                self.__setattr__(ditem, dict_fmerge(self.__getattribute__(ditem), descriptor[ditem]))
-            else: self.__setattr__(ditem, descriptor[ditem])    
+
+        self.description = descriptor
+        self.set_descriptor_attrs()
+
+        if self.id is not None: self.id = str(self.id)
 
         # Add API handler if needed
         if self.source == 'api':
+
             hmod = __import__('scdata.io.device_api', fromlist = ['io.device_api'])
             Hclass = getattr(hmod, self.sources[self.source]['handler'])
+
             # Create object
             self.api_device = Hclass(did = self.id)
 
@@ -95,59 +96,68 @@ class Device(object):
         for bpitem in blueprintd:
             self.__setattr__(bpitem, blueprintd[bpitem])
 
+    def set_descriptor_attrs(self):
+
+        # Descriptor attributes
+        for ditem in self.description.keys():
+            if ditem not in vars(self): std_out (f'Ignoring {ditem} from input', 'WARNING'); continue
+            if type(self.__getattribute__(ditem)) == dict:
+                self.__setattr__(ditem, dict_fmerge(self.__getattribute__(ditem), self.description[ditem]))
+            else: self.__setattr__(ditem, self.description[ditem])
+
     def check_overrides(self, options = {}):
-        
-        if 'min_date' in options.keys(): self.options['min_date'] = options['min_date']
-        else: self.options['min_date'] = self.min_date
 
-        if 'max_date' in options.keys(): self.options['max_date'] = options['max_date']
-        else: self.options['max_date'] = self.max_date
+        if 'min_date' in options.keys():
+            self.options['min_date'] = options['min_date']
+        else:
+            self.options['min_date'] = self.min_date
 
-        if 'clean_na' in options.keys(): self.options['clean_na'] = options['clean_na']
-        else: self.options['clean_na'] = self.clean_na
+        if 'max_date' in options.keys():
+            self.options['max_date'] = options['max_date']
+        else:
+            self.options['max_date'] = self.max_date
 
-        if 'frequency' in options.keys(): self.options['frequency'] = options['frequency']
-        elif self.frequency is not None: self.options['frequency'] = self.frequency
-        else: self.options['frequency'] = '1Min'
+        if 'clean_na' in options.keys():
+            self.options['clean_na'] = options['clean_na']
+        else:
+            self.options['clean_na'] = self.clean_na
+
+        if 'frequency' in options.keys():
+            self.options['frequency'] = options['frequency']
+        elif self.frequency is not None:
+            self.options['frequency'] = self.frequency
+        else:
+            self.options['frequency'] = '1Min'
 
     def load_postprocessing_info(self):
 
-        if self.source != 'api':
-            return None
+        if self.source != 'api': return None
 
-        if self.sources[self.source]['handler'] != 'ScApiDevice':
-            return None
+        if self.sources[self.source]['handler'] != 'ScApiDevice': return None
 
         # Request to get postprocessing information
-        if self.api_device.get_postprocessing_info() is None:
-            return None
+        if self.api_device.get_postprocessing_info() is None: return None
 
         # Put it where it goes
-        self.hw_url = self.api_device.postprocessing_info['hardware_url']
-        self.hw_updated_at = self.api_device.postprocessing_info['updated_at']
-        self.blueprint_url = self.api_device.postprocessing_info['blueprint_url']
-        self.latest_postprocessing = self.api_device.postprocessing_info['latest_postprocessing']
+        try:
+            self.hw_url = self.api_device.postprocessing_info['hardware_url']
+            self.hw_updated_at = self.api_device.postprocessing_info['updated_at']
+            self.blueprint_url = self.api_device.postprocessing_info['blueprint_url']
+            self.latest_postprocessing = self.api_device.postprocessing_info['latest_postprocessing']
+            inc_postprocessing_info = False
+        except KeyError:
+            std_out('Ignoring postprocessing info as its incomplete', 'WARNING')
+            inc_postprocessing_info = True
+            pass
 
-        # Use postprocessing_info blueprint
-        if self.blueprint_url is not None and self.blueprint_loaded_from_url == False:
-            std_out(f'Loading hardware postprocessing blueprint from:\n{self.blueprint_url}')
-            nblueprint = basename(urlparse(self.blueprint_url).path).split('.')[0]
-            std_out(f'Using hardware postprocessing blueprint: {nblueprint}')
-            if nblueprint in config.blueprints:
-                std_out(f'Blueprint from hardware info ({nblueprint}) already in config.blueprints. Overwritting', 'WARNING')
-            lblueprint = get_json_from_url(self.blueprint_url)
-            if lblueprint is not None:
-                std_out('Blueprint loaded from url', 'SUCCESS')
-                self.blueprint = nblueprint
-                self.blueprint_loaded_from_url = True
-                self.set_blueprint_attrs(lblueprint)
-            else:
-                std_out('Blueprint in url is not valid', 'ERROR')
-                return None
+        if inc_postprocessing_info: return None
 
+        # Load hardware info from url
         if self.hw_url is not None and self.hw_loaded_from_url == False:
+
             std_out(f'Loading hardware info from:\n{self.hw_url}')
             lhw_info = get_json_from_url(self.hw_url)
+
             if lhw_info is not None:
                 self.hw_info = lhw_info
                 std_out('Hardware in url is valid', "SUCCESS")
@@ -156,6 +166,65 @@ class Device(object):
                 std_out("Hardware in url is not valid", 'ERROR')
                 return None
 
+        # Use postprocessing_info blueprint (not null case)
+        if self.blueprint_url is not None and self.blueprint_loaded_from_url == False:
+
+            std_out(f'Loading hardware postprocessing blueprint from:\n{self.blueprint_url}')
+            nblueprint = basename(urlparse(self.blueprint_url).path).split('.')[0]
+            std_out(f'Using hardware postprocessing blueprint: {nblueprint}')
+
+            if nblueprint in config.blueprints:
+
+                std_out(f'Blueprint from hardware info ({nblueprint}) already in config.blueprints. Overwritting')
+                # self.blueprint_loaded_from_url = True
+                # return self.api_device.postprocessing_info
+
+            lblueprint = get_json_from_url(self.blueprint_url)
+
+            if lblueprint is not None:
+
+                std_out('Blueprint loaded from url', 'SUCCESS')
+                self.blueprint = nblueprint
+                self.blueprint_loaded_from_url = True
+                self.set_blueprint_attrs(lblueprint)
+                self.set_descriptor_attrs()
+
+            else:
+
+                std_out('Blueprint in url is not valid', 'ERROR')
+                return None
+
+        # Use postprocessing_info blueprint (null case)
+        elif self.blueprint_url is None and self.blueprint_loaded_from_url == False:
+
+            if 'default_blueprint_url' in self.hw_info:
+
+                std_out(f"Loading default hardware postprocessing blueprint from:\n{self.hw_info['default_blueprint_url']}")
+                nblueprint = basename(urlparse(self.hw_info['default_blueprint_url']).path).split('.')[0]
+
+                if nblueprint in config.blueprints:
+                    std_out(f'Default blueprint from hardware info ({nblueprint}) already in config.blueprints. Overwritting', 'WARNING')
+
+                lblueprint = get_json_from_url(self.hw_info['default_blueprint_url'])
+
+                if lblueprint is not None:
+
+                    std_out('Default lueprint loaded from url', 'SUCCESS')
+                    self.blueprint = nblueprint
+                    self.blueprint_loaded_from_url = True
+                    self.set_blueprint_attrs(lblueprint)
+                    self.set_descriptor_attrs()
+
+                else:
+
+                    std_out('Blueprint in url is not valid', 'ERROR')
+                    return None
+
+            else:
+
+                std_out('Postprocessing not possible without blueprint', 'ERROR')
+                return None
+
         return self.api_device.postprocessing_info
 
     def load(self, options = None, path = None, convert_units = True, only_unprocessed = False):
@@ -212,7 +281,7 @@ class Device(object):
 
                         # Override dates for post-processing
                         if self.latest_postprocessing is not None:
-                            hw_latest_postprocess = localise_date(self.latest_postprocessing, self.location)
+                            hw_latest_postprocess = localise_date(self.latest_postprocessing, 'UTC').strftime('%Y-%m-%dT%H:%M:%S')
                             # Override min loading date
                             self.options['min_date'] = hw_latest_postprocess
 
@@ -249,7 +318,6 @@ class Device(object):
                 if not self.readings.empty:
                     self.loaded = True
                     if convert_units: self.__convert_units__()
-
         finally:
             return self.loaded
 
@@ -268,43 +336,30 @@ class Device(object):
 
             for slot in self.hw_info[version]["ids"]:
 
-                # Alphasense type
+                # Alphasense type - AAN 803-04
                 if slot.startswith('AS'):
 
                     sensor_id = self.hw_info[version]["ids"][slot]
                     as_type = config._as_sensor_codes[sensor_id[0:3]]
                     pollutant = as_type[as_type.index('_')+1:]
-                    platform_sensor_id = config._platform_sensor_ids[pollutant]
-                    # TODO - USE POLLUTANT OR PLATFORM SENSOR ID?
-                    process = 'alphasense_803_04'
+                    if pollutant == 'OX': pollutant = 'O3'
 
+                    # Get working and auxiliary electrode names
                     wen = f"ADC_{slot.strip('AS_')[:slot.index('_')]}_{slot.strip('AS_')[slot.index('_')+1]}"
                     aen = f"ADC_{slot.strip('AS_')[:slot.index('_')]}_{slot.strip('AS_')[slot.index('_')+2]}"
 
-                    # metric_name = f'{pollutant}_V{version}_S{list(self.hw_info[version]["ids"]).index(slot)}'
-                    metric_name = f'{pollutant}'
-
-                    metric = {metric_name:
-                                        {
-                                            'process': process,
-                                            'desc': f'Calculation of {pollutant} based on AAN 803-04',
-                                            'units': 'ppb', # always for alphasense sensors,
-                                            'id': platform_sensor_id,
-                                            'post': True,
-                                            'kwargs':  {
-                                                        'from_date': from_date,
-                                                        'to_date': to_date,
-                                                        'alphasense_id': sensor_id,
-                                                        'we': wen,
-                                                        'ae': aen,
-                                                        't': 'EXT_TEMP', # TODO With external temperature?
-                                                        'location': self.location
-                                                        }
-                                        }
-                    }
-
-                self.add_metric(metric)
-
+                    if pollutant not in self.metrics:
+                        # Create Metric
+                        std_out(f'Metric {pollutant} not in blueprint, ignoring.', 'WARNING')
+                    else:
+                        # Simply fill it up
+                        std_out(f'{pollutant} found in blueprint metrics, filling up with hardware info')
+                        self.metrics[pollutant]['kwargs']['we'] = wen
+                        self.metrics[pollutant]['kwargs']['ae'] = aen
+                        self.metrics[pollutant]['kwargs']['location'] = self.location
+                        self.metrics[pollutant]['kwargs']['alphasense_id'] = str(sensor_id)
+                        self.metrics[pollutant]['kwargs']['from_date'] = from_date
+                        self.metrics[pollutant]['kwargs']['to_date'] = to_date
 
     def __check_sensors__(self):
         remove_sensors = list()
@@ -409,8 +464,14 @@ class Device(object):
         if process_ok:
             # Latest postprocessing to latest readings
             if self.api_device.get_postprocessing_info() is not None:
-                latest_postprocessing = localise_date(self.readings.index[-1], self.location).strftime('%Y-%m-%dT%H:%M:%S')
+                std_out('Updating postprocessing_info')
+                latest_postprocessing = localise_date(self.readings.index[-1], 'UTC').strftime('%Y-%m-%dT%H:%M:%S')
                 self.api_device.postprocessing_info['latest_postprocessing'] = latest_postprocessing
+                self.api_device.postprocessing_info['updated_at'] = to_datetime(datetime.datetime.now(), utc = False)\
+                                                                    .tz_localize(config._location)\
+                                                                    .tz_convert('UTC').strftime('%Y-%m-%dT%H:%M:%S')
+                std_out(f"{self.api_device.postprocessing_info}")
+                std_out(f"Device {self.id} processed", "SUCCESS")
 
         return process_ok
 
@@ -498,7 +559,33 @@ class Device(object):
             std_out('Not supported format' ,'ERROR')
             return False
 
-    def post(self, with_post_info = True):
+    def post_sensors(self):
+        '''
+        Posts devices sensors. Only available for parent of ScApiDevice
+        Returns
+        ----------
+            boolean
+            True if posted ok, False otherwise
+        '''
+
+        post_ok = True
+        if self.sources[self.source]['handler'] != 'ScApiDevice':
+            std_out('Only supported processing post is to SmartCitizen API', 'ERROR')
+            return False
+
+        for sensor in self.sensors:
+            std_out(f'Posting sensor: {sensor}')
+            # Get single series for post
+            df = DataFrame(self.readings[sensor]).dropna(axis = 0, how='all')
+            if df.empty: 
+                std_out('Empty dataframe, ignoring', 'WARNING')
+                continue
+            sensor_id = self.sensors[sensor]['id']
+            post_ok &= self.api_device.post_device_data(df, sensor_id = sensor_id)
+
+        return post_ok
+        
+    def post_metrics(self, with_post_info = True):
         '''
         Posts devices metrics. Only available for parent of ScApiDevice
         Parameters
@@ -517,18 +604,23 @@ class Device(object):
             std_out('Only supported processing post is to SmartCitizen API', 'ERROR')
             return False
 
+        std_out(f"Posting metrics for device {self.id}")
         for metric in self.metrics:
             if self.metrics[metric]['post'] == True:
+                std_out(f"Posting {metric} for device {self.id}")
                 # Get single series for post
-                df = DataFrame(self.readings[metric])
+                df = DataFrame(self.readings[metric]).dropna(axis = 0, how='all')
+                if df.empty:
+                    std_out('Empty dataframe, ignoring', 'WARNING')
+                    continue
                 sensor_id = self.metrics[metric]['id']
                 post_ok &= self.api_device.post_device_data(df, sensor_id = sensor_id)
+                if post_ok: std_out(f"Metric {metric} posted", "SUCCESS")
+                else: std_out(f"Error while posting {metric}", "WARNING")
 
         # Post info if requested. It should be updated elsewhere
-        if with_post_info: self.api_device.post_postprocessing_info()
+        if with_post_info and post_ok:
+            post_ok &= self.api_device.post_postprocessing_info()
 
+        if post_ok: std_out(f"Metrics posted for device {self.id}", "SUCCESS")
         return post_ok
-
-    # TODO
-    # def capture(self):
-    #     std_out('Not yet', 'ERROR')
