@@ -17,8 +17,9 @@ from os import environ, urandom
 from json import dumps
 
 import binascii
+from time import sleep
 
-tz_where = tzwhere.tzwhere()
+tz_where = tzwhere.tzwhere(forceTZ=True)
 
 '''
 About the classes in this file:
@@ -29,7 +30,7 @@ There should be at minimum the following properties:
 - sensors: dictionary used to convert the names to saf standard (see saf.py and blueprints.yml) {api_name: saf_name}
 - data: pandas dataframe containing the data. Columns = pollutants or sensors; index = localised timestamp
 Methods
-- get_device_data(start_date, end_date, frequency, clean_na): returns clean pandas dataframe (self.data) with start and end date filtering, and rollup
+- get_device_data(min_date, max_date, frequency, clean_na): returns clean pandas dataframe (self.data) with start and end date filtering, and rollup
 - get_device_location: returns timezone for timestamp geolocalisation
 
 The units should not be converted here, as they will be later on converted in device.py
@@ -118,6 +119,58 @@ class ScApiDevice:
         std_out(f'Error while creating new device, platform returned {backed_device.status_code}', 'ERROR')
         return False
 
+
+    @staticmethod
+    def search_query(key = '', value = None, full = False):
+        """
+        Gets devices from Smart Citizen API based on ransack parameters
+        Basic query documentation: https://developer.smartcitizen.me/#basic-searching
+        Parameters
+        ----------
+            key: string
+                ''
+                Query key according to the basic query documentation. Some (not all) parameters are:
+                ['id', 'owner_id', 'name', 'description', 'mac_address', 'created_at',
+                'updated_at', 'kit_id', 'geohash', 'last_recorded_at', 'uuid', 'state',
+                'postprocessing_info', 'hardware_info']
+            value: string
+                None
+                Query to fit
+                For null, not_null values, use 'null' or 'not_null'
+            full: bool
+                False
+                Returns a list with if False, or the whole dataframe if True
+        Returns
+        -------
+            A list of kit IDs that comply with the requirements, or the full df, depending on full.
+        """
+
+        API_BASE_URL = "https://api.smartcitizen.me/v0/devices/"
+
+        # Value check
+        if value is None: std_out(f'Value needs a value, {value} supplied', 'ERROR'); return None
+
+
+        if value == 'null' or value == 'not_null':
+             query = API_BASE_URL  + f'?q[{key}_{value}]=1'
+        else:
+             query = API_BASE_URL  + f'?q[{key}]={value}'
+
+        try:
+            qresp = get(query)
+
+            # If status code OK, retrieve data
+            if qresp.status_code == 200 or qresp.status_code == 201:
+                df = DataFrame(qresp.json()).set_index('id')
+            else:
+                std_out('API reported {}'.format(qresp.status_code), 'ERROR')
+        except:
+            std_out('Failed request. Probably no connection', 'ERROR')
+            pass
+
+        if full: return df
+        else: return list(df.index)
+
     @staticmethod
     def get_world_map(min_date = None, max_date = None, city = None, within = None, tags = None, tag_method = 'any', full = False):
         """
@@ -151,6 +204,7 @@ class ScApiDevice:
             A list of kit IDs that comply with the requirements, or the full df, depending on full. 
             If no requirements are set, returns all of them
         """
+
         def is_within_circle(x, within):
             if isnan(x['latitude']): return False
             if isnan(x['longitude']): return False
@@ -206,6 +260,13 @@ class ScApiDevice:
         if self.devicejson is None or update:
             try:
                 deviceR = get(self.API_BASE_URL + '{}/'.format(self.id))
+
+                if deviceR.status_code == 429:
+                    std_out('API reported {}. Retrying once'.format(deviceR.status_code),
+                            'WARNING')
+                    sleep(30)
+                    deviceR = get(self.API_BASE_URL + '{}/'.format(self.id))
+
                 if deviceR.status_code == 200 or deviceR.status_code == 201:
                     self.devicejson = deviceR.json()
                 else: 
@@ -264,10 +325,20 @@ class ScApiDevice:
 
         if self.postprocessing_info is None or update:
             try:
-                deviceR = get(self.API_BASE_URL + '{}/postprocessing_info'.format(self.id))
+                deviceR = get(self.API_BASE_URL + '{}'.format(self.id))
+
+                # Retry once
+                if deviceR.status_code == 429:
+                    std_out('API reported {}. Retrying once'.format(deviceR.status_code),
+                            'WARNING')
+                    sleep(30)
+                    deviceR = get(self.API_BASE_URL + '{}'.format(self.id))
+
                 if deviceR.status_code == 200 or deviceR.status_code == 201:
-                    self.postprocessing_info = deviceR.json()
-                    std_out(postprocessing_info, 'ERROR')
+                    if 'postprocessing_info' in deviceR.json():
+                        self.postprocessing_info = deviceR.json()['postprocessing_info']
+                    else:
+                        std_out('Request OK, but no postprocessing_info', 'ERROR')
                 else:
                     std_out('API reported {} when loading postprocessing information'.format(deviceR.status_code), 'WARNING')
             except:
@@ -281,9 +352,9 @@ class ScApiDevice:
         if self.location is None or update:
             latitude, longitude = self.get_device_lat_long(update)
             # Localize it
-            
+
             if latitude is not None and longitude is not None:
-                self.location = tz_where.tzNameAt(latitude, longitude)
+                self.location = tz_where.tzNameAt(latitude, longitude, forceTZ=True)
 
         std_out ('Device {} timezone is {}'.format(self.id, self.location))
 
@@ -328,10 +399,10 @@ class ScApiDevice:
                 self.sensors = dict()
                 for sensor in sensors:
                     for key in config.blueprints:
-                        if not search("sc[k|_]",key): continue
+                        if not search("sc[k|_]", key): continue
                         if 'sensors' in config.blueprints[key]:
                             for sensor_name in config.blueprints[key]['sensors'].keys():
-                                if config.blueprints[key]['sensors'][sensor_name]['id'] == str(sensor['id']):
+                                if str(config.blueprints[key]['sensors'][sensor_name]['id']) == str(sensor['id']):
                                     # IDs are unique
                                     self.sensors[sensor['id']] = sensor_name
 
@@ -357,7 +428,15 @@ class ScApiDevice:
         rollup = rollup_value + rollup_unit
         return rollup
 
-    def get_device_data(self, start_date = None, end_date = None, frequency = '1Min', clean_na = None):
+    def get_device_data(self, min_date = None, max_date = None, frequency = '1Min', clean_na = None):
+
+        if 'SC_ADMIN_BEARER' in environ:
+            std_out('Admin Bearer found, using it', 'SUCCESS')
+
+            headers = {'Authorization':'Bearer ' + environ['SC_ADMIN_BEARER']}
+        else:
+            headers = None
+            std_out('Admin Bearer not found' 'WARNING')
 
         std_out(f'Requesting data from SC API')
         std_out(f'Device ID: {self.id}')
@@ -372,38 +451,26 @@ class ScApiDevice:
         self.get_device_added_at()
         self.get_kit_ID()
 
-        if self.location is None: return None
+        if self.location is None: 
+            std_out('Device does not have location, skipping', 'WARNING')
+            return None
 
-        # Check start date
-        # if start_date is None and self.added_at is not None:
-        #     start_date = localise_date(to_datetime(self.added_at, format = '%Y-%m-%dT%H:%M:%SZ'), self.location)
-        #     # to_datetime(self.added_at, format = '%Y-%m-%dT%H:%M:%SZ')
-        # elif start_date is not None:
-        #     start_date = to_datetime(start_date, format = '%Y-%m-%dT%H:%M:%SZ')
-        if start_date is not None:
-            start_date = localise_date(to_datetime(start_date, format = '%Y-%m-%dT%H:%M:%SZ'), self.location)
+        # Check start date and end date
+        # Converting to UTC by passing None
+        # https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.Series.dt.tz_convert.html
+        if min_date is not None:
+            min_date = localise_date(to_datetime(min_date), 'UTC').strftime('%Y-%m-%dT%H:%M:%S')
+            std_out (f'Min Date: {min_date}')
+        else:
+            min_date = localise_date(to_datetime('2001-01-01'), 'UTC').strftime('%Y-%m-%dT%H:%M:%S')
+            std_out(f"No min_date specified")
         
-        # if start_date.tzinfo is None: start_date = start_date.tz_localize('UTC').tz_convert(self.location)
-            std_out (f'Min Date: {start_date}')
-        
-        # # Check end date
-        # if end_date is None and self.last_reading_at is not None:
-        #     # end_date = to_datetime(self.last_reading_at, format = '%Y-%m-%dT%H:%M:%SZ')
-        #     end_date = localise_date(to_datetime(self.last_reading_at, format = '%Y-%m-%dT%H:%M:%SZ'), self.location)
-        # elif end_date is not None:
-        #     end_date = to_datetime(end_date, format = '%Y-%m-%dT%H:%M:%SZ')
-        if end_date is not None:
-            end_date = localise_date(to_datetime(end_date, format = '%Y-%m-%dT%H:%M:%SZ'), self.location)
-        
-        # if end_date.tzinfo is None: end_date = end_date.tz_localize('UTC').tz_convert(self.location)
-        
-            std_out (f'Max Date: {end_date}')
+        if max_date is not None:
+            max_date = localise_date(to_datetime(max_date), 'UTC').strftime('%Y-%m-%dT%H:%M:%S')
+            std_out (f'Max Date: {max_date}')
 
-        # if start_date > end_date: std_out('Ignoring device dates. Probably SD card device', 'WARNING')
-        
         # Print stuff
         std_out('Kit ID: {}'.format(self.kit_id))
-        # if start_date < end_date: std_out(f'Dates: from: {start_date}, to: {end_date}')
         std_out(f'Device timezone: {self.location}')
         if not self.sensors.keys(): 
             std_out(f'Device is empty')
@@ -411,35 +478,33 @@ class ScApiDevice:
         else: std_out(f'Sensor IDs: {list(self.sensors.keys())}')
 
         df = DataFrame()
-        
         # Get devices in the sensor first
         for sensor_id in self.sensors.keys(): 
 
             # Request sensor per ID
             request = self.API_BASE_URL + '{}/readings?'.format(self.id)
-            
-            if start_date is None:
-                request += 'from=2001-01-01'
-            elif end_date is not None:
-                if start_date > end_date: request += 'from=2001-01-01'
-                else: 
-                    request += f'from={start_date}'
-                    request += f'&to={end_date}'
+
+            if min_date is not None: request += f'from={min_date}'
+            if max_date is not None: request += f'&to={max_date}'
 
             request += f'&rollup={rollup}'
             request += f'&sensor_id={sensor_id}'
             request += '&function=avg'
-            # if end_date is not None:
-            #     if end_date > start_date: request += f'&to={end_date}'
             
             # Make request
-            sensor_req = get(request)
+            sensor_req = get(request, headers = headers)
+
+            # Retry once in case of 429 after 30s
+            if sensor_req.status_code == 429:
+                std_out('Too many requests, waiting for 1 more retry', 'WARNING')
+                sleep (30)
+                sensor_req = get(request, headers = headers)
+
             flag_error = False
             try:
                 sensorjson = sensor_req.json()
             except:
-                print_exc()
-                std_out('Problem with json data from API', 'ERROR')
+                std_out(f'Problem with json data from API, {sensor_req.status_code}', 'ERROR')
                 flag_error = True
                 pass
                 continue
@@ -512,11 +577,11 @@ class ScApiDevice:
             -------
                 True if the data was posted succesfully
         '''
-        if 'SC_ADMIN_BEARER' not in environ:
+        if 'SC_BEARER' not in environ:
             std_out('Cannot post without Auth Bearer', 'ERROR')
             return
 
-        headers = {'Authorization':'Bearer ' + environ['SC_ADMIN_BEARER'], 'Content-type': 'application/json'}
+        headers = {'Authorization':'Bearer ' + environ['SC_BEARER'], 'Content-type': 'application/json'}
 
         # Get sensor name
         sensor_name = list(df.columns)[0]
@@ -546,6 +611,7 @@ class ScApiDevice:
 
         response = post(f'https://api.smartcitizen.me/v0/devices/{self.id}/readings', data = payload_json, headers = headers)
         if response.status_code == 200 or response.status_code == 201:
+            std_out('Post OK', 'SUCCESS')
             return True
 
         return False
@@ -554,11 +620,12 @@ class ScApiDevice:
         '''
             POST postprocessing info into the device in the SmartCitizen API
             Updates all the post info. Changes need to be made info the keys of the postprocessing_info outside of here
+            Needs to post the whole json
 
             # Example postprocessing_info:
             # {
             #   "updated_at": "2020-10-29T04:35:23Z",
-            #   "postprocessing_blueprint": 'sck_21_gps',
+            #   "blueprint_url": "https://github.com/fablabbcn/smartcitizen-data/blob/master/blueprints/sc_21_station_module.json",
             #   "hardware_url": "https://raw.githubusercontent.com/fablabbcn/smartcitizen-data/master/hardware/SCAS210001.json",
             #   "latest_postprocessing": "2020-10-29T08:35:23Z"
             # }
@@ -568,14 +635,20 @@ class ScApiDevice:
             std_out('Cannot post without Auth Bearer', 'ERROR')
             return
 
-        headers = {'Authorization':'Bearer ' + environ['SC_BEARER'], 'Content-type': 'application/json'}
+        headers = {'Authorization':'Bearer ' + environ['SC_BEARER'],
+                   'Content-type': 'application/json'}
 
-        post_json = dumps(self.postprocessing_info)
+        post = {"postprocessing_info": self.postprocessing_info}
+        post_json = dumps(post)
         std_out(f'Posting post-processing info:\n {post_json}')
-        response = patch(f'https://api.smartcitizen.me/v0/devices/{self.id}/', data = post_json, headers = headers)
+        response = patch(f'https://api.smartcitizen.me/v0/devices/{self.id}/',
+                         data = post_json, headers = headers)
 
         if response.status_code == 200 or response.status_code == 201:
+            std_out(f"Postprocessing info posted", "SUCCESS")
             return True
+        else:
+            std_out(f"API responded with {response.status_code}")
 
         return False
 
@@ -604,9 +677,9 @@ class MuvApiDevice:
                         self.sensors[config.blueprints[key]['sensors'][sensor_name]['id']] = sensor_name
         return self.sensors
 
-    def get_device_data(self, start_date = None, end_date = None, frequency = '3Min', clean_na = None):
+    def get_device_data(self, min_date = None, max_date = None, frequency = '3Min', clean_na = None):
 
-        if start_date is not None: days_ago = (to_datetime(date.today())-to_datetime(start_date)).days
+        if min_date is not None: days_ago = (to_datetime(date.today())-to_datetime(min_date)).days
         else: days_ago = 365 # One year of data
 
         std_out(f'Requesting data from MUV API')
@@ -833,7 +906,7 @@ class DadesObertesApiDevice:
         
         return (self.lat, self.long)
 
-    def get_device_data(self, start_date = None, end_date = None, frequency = '1H', clean_na = None):
+    def get_device_data(self, min_date = None, max_date = None, frequency = '1H', clean_na = None):
         '''
         Based on code snippet from Marc Roig:
         # I2CAT RESEARCH CENTER - BARCELONA - MARC ROIG (marcroig@i2cat.net)
@@ -847,13 +920,13 @@ class DadesObertesApiDevice:
         request = self.API_BASE_URL
         request += f'codi_eoi={self.id}'
 
-        if start_date is not None and end_date is not None:
-            request += "&$where=data between " + to_datetime(start_date).strftime("'%Y-%m-%dT%H:%M:%S'") \
-                    + " and " + to_datetime(end_date).strftime("'%Y-%m-%dT%H:%M:%S'")
-        elif start_date is not None:
-            request += "&$where=data >= " + to_datetime(start_date).strftime("'%Y-%m-%dT%H:%M:%S'")
-        elif end_date is not None:
-            request += "&$where=data < " + to_datetime(end_date).strftime("'%Y-%m-%dT%H:%M:%S'")
+        if min_date is not None and max_date is not None:
+            request += "&$where=data between " + to_datetime(min_date).strftime("'%Y-%m-%dT%H:%M:%S'") \
+                    + " and " + to_datetime(max_date).strftime("'%Y-%m-%dT%H:%M:%S'")
+        elif min_date is not None:
+            request += "&$where=data >= " + to_datetime(min_date).strftime("'%Y-%m-%dT%H:%M:%S'")
+        elif max_date is not None:
+            request += "&$where=data < " + to_datetime(max_date).strftime("'%Y-%m-%dT%H:%M:%S'")
 
         try:
             s = get(request)
