@@ -8,20 +8,22 @@ from datetime import datetime
 import yaml
 import json
 import folium
+from re import sub
 
 from scdata.utils import std_out, get_tests_log
 from scdata.io import read_csv_file
 from scdata._config import config
 from scdata.device import Device
+from scdata.test.plot.plot_tools import to_png_b64
 
 class Test(object):
 
-    from .plot import (ts_plot, ts_iplot, device_metric_map,
+    from .plot import (ts_plot, ts_iplot, ts_uplot, device_metric_map,
                         scatter_plot, scatter_iplot, ts_scatter,
                         heatmap_plot, heatmap_iplot,
                         box_plot, ts_dendrogram)
                         #, report_plot, cat_plot, violin_plot)
-    from .export import to_csv, desc_to_html
+    from .export import to_csv, to_html
     from .load import load
     from .utils import combine, prepare
 
@@ -30,7 +32,8 @@ class Test(object):
         self.options = {  
                         'cached_data_margin': config.data['cached_data_margin'],
                         'load_cached_api': config.data['load_cached_api'],
-                        'store_cached_api': config.data['store_cached_api']
+                        'store_cached_api': config.data['store_cached_api'],
+                        'clean_na': config.data['clean_na']
                         }
 
         if self.__check_tname__(name): self.__set_tname__(name)
@@ -56,6 +59,9 @@ class Test(object):
                                 'type_test': ''
                                 }
 
+        # Dict for report
+        self.content = dict()
+
     def __str__(self):
         return self.full_name
 
@@ -161,6 +167,31 @@ class Test(object):
         if device.id not in self.devices.keys(): self.devices[device.id] = device
         else: std_out(f'Device {device.id} is duplicated', 'WARNING')
 
+    def add_content(self, title = None, figure = None, text = None, iframe = None):
+        '''
+            Adds content for the rendered flask template of the test
+        '''
+
+        title_cor = sub('\W|^(?=\d)','_', title)
+
+        if title_cor not in self.content:
+            self.content[title_cor] = dict()
+
+            if title is not None:
+                self.content[title_cor]['title'] = title
+            if figure is not None:
+                self.content[title_cor]['image'] = to_png_b64(figure)
+            if text is not None:
+                self.content[title_cor]['text'] = text
+            if iframe is not None:
+                self.content[title_cor]['iframe'] = iframe
+
+            return True
+
+        else:
+
+            return False
+
     def process(self, only_new = False):
         ''' 
         Calculates all the metrics in each of the devices
@@ -180,15 +211,27 @@ class Test(object):
         Calculates only the new metrics in each of the devices
         Returns True if done OK
         '''
-        return self.process(only_new = True)     
+        return self.process(only_new = True)
 
     def __set_options__(self, options):
-        if 'load_cached_api' in options.keys(): self.options['load_cached_api'] = options['load_cached_api']
-        if 'store_cached_api' in options.keys(): self.options['store_cached_api'] = options['store_cached_api']
-        if 'clean_na' in options.keys(): self.options['clean_na'] = options['clean_na']
-        if 'frequency' in options.keys(): self.options['frequency'] = options['frequency']
-        if 'min_date' in options.keys(): self.options['min_date'] = options['min_date'] 
-        if 'max_date' in options.keys(): self.options['max_date'] = options['max_date']
+
+        if 'load_cached_api' in options.keys():
+            self.options['load_cached_api'] = options['load_cached_api']
+
+        if 'store_cached_api' in options.keys():
+            self.options['store_cached_api'] = options['store_cached_api']
+
+        if 'clean_na' in options.keys():
+            self.options['clean_na'] = options['clean_na']
+
+        if 'frequency' in options.keys():
+            self.options['frequency'] = options['frequency']
+
+        if 'min_date' in options.keys():
+            self.options['min_date'] = options['min_date']
+
+        if 'max_date' in options.keys():
+            self.options['max_date'] = options['max_date']
 
     def __preprocess__(self):
         '''
